{% extends "admin/change_list.html" %}
{% load add_preserved_filters from admin_urls %}

{% block object-tools-items %}
    {% for tool in objectactions %}
        <li class="objectaction-item" data-tool-name="{{ tool.name }}">
            {% url tools_view_name tool=tool.name as action_url %}
            <a href="{% add_preserved_filters action_url %}" title="{{ tool.standard_attrs.title }}" {% for k, v in tool.custom_attrs.items %}{{ k }}="{{ v }}"{% endfor %} class="{{ tool.standard_attrs.class }}">
                {{ tool.label|capfirst }}
            </a>
        </li>
    {% endfor %}
    {{ block.super }}
{% endblock object-tools-items %}
