{% if widget.name|slice:":5" == 'form-' %}<div class="form-check form-switch">{% endif %}

    <input type="{{ widget.type }}"
           name="{{ widget.name }}"
           {% if widget.value != None %}value="{{ widget.value|stringformat:'s' }}"{% endif %}
           {% include "django/forms/widgets/attrs.html" %}
           {% include "django/forms/widgets/classes.html" %} />
 
    {% if widget.name|slice:":5" == 'form-' %}</div>{% endif %}
